using System;
using System.Data;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Web.UI.HtmlControls;
using Telerik.WebControls;
using System.Data.OleDb;

public partial class _Default : Page
{
	private readonly string ConnectionString = ConfigurationManager.ConnectionStrings["TreeConnectionString"].ConnectionString;

	private void GenerateTreeView()
	{
		using (OleDbConnection dbCon = new OleDbConnection(ConnectionString))
		{
			dbCon.Open();

			OleDbDataAdapter adapter = new OleDbDataAdapter("SELECT ID, ParentID, [Order], [Text] FROM Links ORDER BY Order ASC", dbCon);
			DataSet ds = new DataSet();
			adapter.Fill(ds);

			ds.Relations.Add("NodeRelation", ds.Tables[0].Columns["Order"], ds.Tables[0].Columns["parentId"]);

			foreach (DataRow dbRow in ds.Tables[0].Rows)
			{
				if (dbRow.IsNull("parentId"))
				{
					RadTreeNode node = CreateNode(dbRow["Text"].ToString(), true, dbRow["Order"].ToString(), dbRow["ID"].ToString());
					RadTreeView1.Nodes.Add(node);
					RecursivelyPopulate(dbRow, node);
				}
			}
		}
	}

	private void RecursivelyPopulate(DataRow dbRow, RadTreeNode node)
	{
		foreach (DataRow childRow in dbRow.GetChildRows("NodeRelation"))
		{
			RadTreeNode childNode = CreateNode(childRow["Text"].ToString(), true, childRow["Order"].ToString(), childRow["id"].ToString());
			node.Nodes.Add(childNode);
			RecursivelyPopulate(childRow, childNode);
		}
	}

	private RadTreeNode CreateNode(string text, bool expanded, string order, string id)
	{
		RadTreeNode node = new RadTreeNode(text, order);
		node.Attributes["ID"] = id;
		node.Expanded = expanded;

		return node;
	}

	private void Page_Load(object sender, System.EventArgs e)
	{
		if (!Page.IsPostBack)
		{
			GenerateTreeView();
		}
	}

	protected void RadTreeView1_NodeDrop(object o, RadTreeNodeEventArgs e)
	{
		RadTreeNode sourceNode = e.SourceDragNode;
		RadTreeNode destNode = e.DestDragNode;
		RadTreeViewDropPosition dropPosition = e.DropPosition;

		if (destNode != null)//drag&drop is performed between trees
		{
			if (sourceNode.Equals(destNode) || sourceNode.IsAncestorOf(destNode))
			{
				return;
			}
			sourceNode.Owner.Nodes.Remove(sourceNode);

			switch (dropPosition)
			{
				case RadTreeViewDropPosition.Over:
					// child
					if (!sourceNode.IsAncestorOf(destNode))
					{
						destNode.Nodes.Add(sourceNode);
					}
					break;

				case RadTreeViewDropPosition.Above:
					// sibling - above        
					Update(sourceNode.Value, destNode.Text);
					Update(destNode.Value, sourceNode.Text);
					destNode.InsertBefore(sourceNode);
					RadTreeView1.Nodes.Clear();
					GenerateTreeView();
					break;

				case RadTreeViewDropPosition.Below:
					Update(sourceNode.Value, destNode.Text);
					Update(destNode.Value, sourceNode.Text);
					destNode.InsertAfter(sourceNode);

					RadTreeView1.Nodes.Clear();
					GenerateTreeView();
					break;
			}
		}
	}

	private void SwitchNodes(RadTreeNode sourceNode, RadTreeNode destNode)
	{
		UpdateNodeOrder(sourceNode.Value, sourceNode.Parent.Attributes["ID"], destNode.Attributes["ID"]);
		UpdateNodeOrder(destNode.Value, sourceNode.Text);
	}

	protected void UpdateNodeOrder(string newOrder, string newParentId, string id)
	{
		OleDbConnection con = new OleDbConnection("Provider=Microsoft.Jet.OLEDB.4.0;Data Source=" + Server.MapPath("~/App_Data/Tree.mdb"));
		con.Open();

		OleDbCommand command = new OleDbCommand("UPDATE Links SET Order=@NewOrder  WHERE Id= @", con);

		command.Parameters.AddWithValue("Text", text);
		command.Parameters.AddWithValue("NewValue1", index);
		//   command.Parameters.Add("@newValue2", parentid);

		int x = command.ExecuteNonQuery();
		Response.Write(x);

		con.Close();
	}

}
